import time
from calendar import monthrange

from netforce.model import Model,fields,get_model

class ReportLaborCostStaff(Model):
    _name="clinic.report.labor.cost.staff"
    _string="Report Labor Cost Staff"
    _transient=True
    
    _fields={
        "date": fields.Date("Month"),
        "date_from": fields.Date("From", required=True),
        "date_to": fields.Date("To", required=True),
        "branch_id": fields.Many2One("clinic.branch","Branch"),
        "cycle_id": fields.Many2One("clinic.cycle","Cycle"),
        "department_id": fields.Many2One("clinic.department","Department"),
        'walkin': fields.Boolean("Walkin"),
    }

    def _get_date_from(self,context={}):
        year,month,day=time.strftime("%Y-%m-%d").split("-")
        #return '%s-%s-01'%(year,month)
        return '%s-%s-%s'%(year,month,day)

    def _get_date_to(self,context={}):
        year,month,day=time.strftime("%Y-%m-%d").split("-")
        weekday, total_day=monthrange(int(year), int(month))
        #return "%s-%s-%s"%(year,month,total_day)
        return "%s-%s-%s"%(year,month,day)

    def default_get(self,field_names=None,context={},**kw):
        defaults=context.get("defaults",{})
        date_from=defaults.get("date_from", self._get_date_from())
        date_to=defaults.get("date_to", self._get_date_to())
        walkin=defaults.get("walkin", False)
        department_id=defaults.get("department_id") or None
        if department_id:
            department_id=int(department_id)
        branch_id=defaults.get("branch_id") or None
        if branch_id:
            branch_id=int(branch_id)
        if walkin and walkin=='False':
            walkin=False
        else:
            walkin=True
        print('defaults ', defaults)
        res={
            'date': time.strftime("%Y-%m-%d"),
            'date_from': date_from,
            'date_to': date_to,
            'walkin': walkin,
            'department_id': department_id,
            'branch_id': branch_id,
        }
        return res
    
    def get_report_data(self,ids,context={}):
        defaults=self.default_get(context=context)
        date_from=defaults['date_from']
        date_to=defaults['date_to']
        branch_id=defaults.get("branch_id")
        department_id=defaults.get("department_id")
        cycle_id=defaults.get("cycle_id")
        walkin=defaults.get("walkin")
        print('walkin ', walkin)
        dom=[]
        if ids:
            obj=self.browse(ids)[0]
            date_from=obj.date_from
            date_to=obj.date_to
            branch_id=obj.branch_id.id
            department_id=obj.department_id.id
            cycle_id=obj.cycle_id.id
            walkin=obj.walkin
        dom.append(['hd_case_id.date','>=',date_from]) #XXX
        dom.append(['hd_case_id.date','<=',date_to]) #XXX
        dom.append(['hd_case_id.state','in',['waiting_payment','paid']])
        if branch_id:
            dom.append(['hd_case_id.branch_id','=',branch_id])
        if department_id:
            dom.append(['hd_case_id.department_id','=',department_id])
        if cycle_id:
            dom.append(['hd_case_id.cycle_id','=',cycle_id])
        lines=[]
        print('dom ', dom)
        for sline in get_model("clinic.hd.case.staff").search_browse(dom):
            hdcase=sline.hd_case_id
            staff=sline.staff_id
            patient=hdcase.patient_id
            if walkin:
                if staff and staff.number!='walkin':
                    continue
            else:
                if staff.number=='walkin':
                    continue
            lines.append({
                'id': sline.id,
                'date': sline.date,
                'number': hdcase.number or '',
                'staff_name': staff.name or '',
                'staff_id': staff.id or None,
                'patient_id': patient.id or None,
                'patient_name': patient.name or None,
                'department_name': sline.department_id.name or '',
                'date': sline.date,
            })
        nlines=[]
        no=1
        for line in sorted(lines,key=lambda x: (x['date'],x['number'])):
            line['no']=no
            nlines.append(line)
            no+=1
        data={
            'date_from': date_from,
            'date_to': date_to,
            'lines': nlines,
        }
        return data

    def onchange_date(self,context={}):
        data=context['data']
        date=data['date']
        year,month,day=date.split("-")
        weekday, total_day=monthrange(int(year), int(month))
        data['date_from']="%s-%s-01"%(year,month)
        data['date_to']="%s-%s-%s"%(year,month,total_day)
        return data

    def onchange_branch(self,context={}):
        data=context['data']
        data['department_id']=None
        return data

    def onchange_from(self,context={}):
        data=context['data']
        data['date_to']=data['date_from']
        return data

ReportLaborCostStaff.register()
